<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8"/>

    <link rel="stylesheet" href="../style.css"/>
    <link rel="stylesheet" href="admin.css"/>
    <meta name="viewport" content="width=device-width, maximum-scale=1.0"/>

    <title>Arts and Events - Edit Confirmation</title>
</head>

<body>

<!-- Page header - contains background image of tyne bridge -->
<header>
    <!-- Page title - contains only h1 of the page -->
    <div class="page_title">
        <h1>Arts and Events</h1>
        <small>Newcastle</small>
    </div>

    <!-- Navigation - uses an unordered list -->
    <nav>
        <ul>
            <li><a href="../index.html">Exit Admin Area</a></li>
        </ul>
    </nav>
</header>

<!-- Main content of page - contained within a flex_wrapper div -->
<div class="flex_wrapper">
    <main>
        <!-- Main article - largest part of the page -->
        <article>
            <?php
            include "../db.php";

            $eventId = isset($_REQUEST["id"]) ? $_REQUEST["id"] : null;
            $eventTitle = isset($_REQUEST["title"]) ? $_REQUEST["title"] : null;
            $eventCategory = isset($_REQUEST["category"]) ? $_REQUEST["category"] : null;
            $eventDescription = isset($_REQUEST["description"]) ? $_REQUEST["description"] : null;
            $eventFrom = isset($_REQUEST["from"]) ? $_REQUEST["from"] : null;
            $eventTo = isset($_REQUEST["to"]) ? $_REQUEST["to"] : null;
            $eventPrice = isset($_REQUEST["price"]) ? $_REQUEST["price"] : null;
            $eventLocation = isset($_REQUEST["location"]) ? $_REQUEST["location"] : null;

            $error = null;

            $parseEventFrom = date_parse($eventFrom);
            $parseEventTo = date_parse($eventTo);

            if (empty($eventId)) {
                $error = "All events must have an ID";
            } else if (empty($eventTitle)) {
                $error = "All events must have a title";
            } else if (empty($eventPrice)) {
                $error = "All events must have a description";
            } else if (empty($eventCategory)) {
                $error = "All events must have a category";
            } else if (empty($eventPrice) || $eventPrice < 0) {
                $error = "The price of an event must be zero (free) or more.";
            } else if (!empty($parseEventFrom["errors"])) {
                $error = "The date $eventFrom was formatted incorrectly. Make sure it's in the format YYYY-MM-DD.";
            } else if (!empty($parseEventTo["errors"])) {
                $error = "The date $eventTo was formatted incorrectly. Make sure it's in the format YYYY-MM-DD.";
            } else if (strtotime($eventFrom) > strtotime($eventTo)) {
                $error = "The date $eventTo must come after $eventFrom.";
            }

            if (empty($error)) {
                $updateSql = "UPDATE AE_events
                              set 
                                  eventTitle = ?, 
                                  eventDescription = ?, 
                                  venueID = ?, 
                                  catID = ?,
                                  eventStartDate = ?, 
                                  eventEndDate = ?, 
                                  eventPrice = ?
                              WHERE eventId = ?";

                $statement = $db->prepare($updateSql);
                $statement->bind_param(
                    "ssssssdi", // the types of the vars to add
                    $eventTitle, $eventDescription,
                    $eventLocation, $eventCategory, $eventFrom,
                    $eventTo, $eventPrice, $eventId
                );

                $statement->execute();

                $sql = "select
                        eventTitle, eventDescription, venueName, location,
                        catDesc, eventStartDate, eventEndDate, eventPrice
                    from AE_events
                        JOIN AE_category
                        ON AE_category.catID = AE_events.catID
                        JOIN AE_venue
                        ON AE_venue.venueID = AE_events.venueID
                    where eventID = {$eventId}";

                $queryResult = $db->query($sql);
                if ($queryResult === false) {
                    echo "\t<p>Unable to retrieve inserted event: " . $db->error . "</p>\n";
                } else {
                    $rowObj = $queryResult->fetch_object();
                    echo "<h2>The event is now the following:</h2>";

                    $price = $rowObj->eventPrice == 0.00 ? "Free" : "£" . $rowObj->eventPrice;
                    echo "<div class='event'>\n";
                    echo "<div class='title'>\n";
                    echo "<h4>{$rowObj->eventTitle}</h4>\n";
                    echo "<small>{$rowObj->catDesc}</small>";
                    echo "</div>";
                    echo "<p>{$rowObj->eventDescription}</p>\n";

                    echo "<ul class='small'>\n";
                    echo "<li>Where: {$rowObj->venueName} in {$rowObj->location}</li>\n";
                    echo "<li>When: {$rowObj->eventStartDate} to {$rowObj->eventEndDate}</li>\n";
                    echo "<li>Price: $price</li>\n";
                    echo "</ul>\n";

                    echo "</div>\n";


                    echo "<a class=\"button\" href=\"edit.php?id=$eventId\"><button>Return to the editor</button></a>";
                    echo "<a class=\"button\" href=\"index.php\"><button>Return to the admin area</button></a>";
                }

            } else {
                echo "<h2>Unable to edit the event</h2>";
                echo "<p>$error</p>";

                if ($eventId != null) {
                    echo "<a class=\"button\" href=\"edit.php?id=$eventId\"><button>Return to the editor</button></a>";
                }

                echo "<a class=\"button\" href=\"index.php\"><button>Return to the admin area</button></a>";

            }
            ?>
        </article>

        <aside>
            <?php
                echo "<div class='float_box'>";
                echo "<img src='../imgs/$eventCategory.jpg' alt='Image representing a {$rowObj->catDesc}'/>";
                echo "</div>";
            ?>
        </aside>
    </main>
</div>

<!-- Page footer - same width as rest of the page -->
<footer>
    <p>&copy; Arts and Events 2016</p>
    <p>Want to get in touch? Call us: 0191 2948023</p>
</footer>


</body>
</html>
